@@ -2,9 +2,9 @@ package Shipwright;
 
 use warnings;
 use strict;
-use version; our $VERSION = qv('2.4.18');
+use version; our $VERSION = qv('2.4.19');
 
-use base qw/Class::Accessor::Fast/;
+use base qw/Shipwright::Base/;
 
 __PACKAGE__->mk_accessors(qw/backend source build log_level log_file/);
 
